@@ -150,4 +150,19 @@ def test_get_compute_pool():
         logger.info("%s, %d, %d, %s", response.get("id"), response.get("status").get("current_cfu"), response.get("spec").get("max_cfu"), response.get("status").get("phase"))    
     except AssertionError as e:
         logger.error(e)
-        logger.error("Error Message: %s, Response: %s", error_message, response)
\ No newline at end of file
+        logger.error("Error Message: %s, Response: %s", error_message, response)
+
+
+def test_stop_statement():
+    """Test the pause_statement() function."""
+
+    # Instantiate the FlinkClient classs.
+    flink_client = FlinkClient(config)
+
+    http_status_code, response = flink_client.stop_statement(statement_name, True)
+ 
+    try:
+        assert http_status_code == HttpStatus.OK, f"HTTP Status Code: {http_status_code}"
+    except AssertionError as e:
+        logger.error(e)
+        logger.error("Response: %s", response)
